@@ -2,7 +2,7 @@
 
 from __future__ import absolute_import, unicode_literals
 
-from django.utils import six
+import six
 from rest_framework import fields
 
 
